<?php

namespace App\Controller;

use App\Controller\BaseController;
use App\Entity\Dil;
use App\Entity\Modul;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use App\Entity\Ayarlar;
use App\Entity\Kategori;
use App\Entity\Sayfa;
use App\Entity\Slider;

class PanelDilController extends BaseController
{
    /**
     * @Route("/rv/dil", name="dil_homepage")
     */
    public function index(): Response
    {
        return $this->render('panel/dil/index.html.twig');
    }

    /**
     * @Route("/rv/dil/getir", name="dil_getir")
     */
    public function getir(): Response {
        $em = $this->getDoctrine()->getManager();

        $qb = $em->createQueryBuilder();
        $diller=$qb->select('d.id,d.kisa,d.uzun,d.aktif,d.varsayilan')
            ->from('App:Dil', 'd')
            ->orderBy('d.aktif','DESC')
            ->getQuery()
            ->getScalarResult();



        return $this->render('panel/dil/getir.html.twig',array('diller'=>$diller));

    }

    /**
     * @Route("/rv/dil/aktif", name="dil_aktif")
     */
    public function aktif(Request $request): Response {
        $em = $this->getDoctrine()->getManager();

        $id = $request->request->get('id');
        $aktif = $request->request->get('aktif');

        $gecerliDil = $this->gecerliAktifDil();




        if($aktif==1){

            $qb = $em->createQueryBuilder();
            $gelenDil=$qb->select('d.kisa,d.id')
                ->from('App:Dil', 'd')
                ->where('d.id='.$id)
                ->getQuery()
                ->getScalarResult();
            $dilSecim = $em->getReference(Dil::class,$id);


            // Ayar Güncelleme
            $qb = $em->createQueryBuilder();
            $ayarBul=$qb->select('a')
                ->from('App:Ayarlar', 'a')
                ->join('a.dil','d')
                ->where("d.id = $gecerliDil")
                ->orderBy('d.id')
                ->getQuery()
                ->getScalarResult();

            if(empty($ayarBul[0]['a_keywords'])){$ayarBul[0]['a_keywords']=null;}else{$ayarBul[0]['a_keywords']=$this->ceviri($ayarBul[0]['a_keywords'],$id);}
            if(empty($ayarBul[0]['a_description'])){$ayarBul[0]['a_description']=null;}else{$ayarBul[0]['a_description']=$this->ceviri($ayarBul[0]['a_description'],$id);}


            $x = new Ayarlar();
            $x->setDil($dilSecim);
            $x->setSiteAdi($ayarBul[0]['a_siteAdi']);
            $x->setSiteYolu($ayarBul[0]['a_siteYolu']);
            $x->setLogo($ayarBul[0]['a_logo']);
            $x->setBeyazLogo($ayarBul[0]['a_beyazLogo']);
            $x->setFavicon($ayarBul[0]['a_favicon']);
            $x->setOzelHead($ayarBul[0]['a_ozelHead']);
            $x->setTitle($this->ceviri($ayarBul[0]['a_title'],$id));
            $x->setKeywords($ayarBul[0]['a_keywords']);
            $x->setDescription($ayarBul[0]['a_description']);
            $x->setRegion(strtoupper($gelenDil[0]['kisa'].'-'.$gelenDil[0]['kisa']));
            $x->setPlaceName('Ülke adı');
            $x->setPosition('0;0');
            $x->setWhatsapp($ayarBul[0]['a_whatsapp']);
            $x->setSistemPosta($ayarBul[0]['a_sistemPosta']);
            $x->setSlider($ayarBul[0]['a_slider']);
            $x->setDebug($ayarBul[0]['a_debug']);
            $x->setHataPage($ayarBul[0]['a_hataPage']);
            $x->setBEposta($ayarBul[0]['a_bEposta']);
            $x->setUploadFolder($ayarBul[0]['a_uploadFolder']);
            $em->persist($x);
            $em->flush();

            //Slider Güncelleme
            $qb = $em->createQueryBuilder();
            $sliderBul=$qb->select('s.baslik,s.aciklama,s.dilgrup,s.resim,d.kisa as dKisa')
                ->from('App:Slider', 's')
                ->join('s.dil','d')
                ->where('d.aktif=1')
                ->groupby('s.dilgrup')
                ->orderBy('d.id')
                ->getQuery()
                ->getScalarResult();

            foreach ($sliderBul as $ssB){
                $slider = new Slider();
                $slider->setBaslik($this->ceviri($ssB['baslik'],$id));
                $slider->setAciklama($this->ceviri($ssB['aciklama'],$id));
                $slider->setDilgrup($ssB['dilgrup']);
                $slider->setResim('');
                $slider->setDil($dilSecim);
                $slider->setSira(0);
                $em->persist($slider);
                $em->flush();
            }


            //Kategori Güncelleme
            $qb = $em->createQueryBuilder();
            $ayarBul=$qb->select('a,s.id as s_id')
                ->from('App:Kategori', 'a')
                ->join('a.dil','d')
                ->join('a.sayfa','s')
                ->where("d.id = $gecerliDil")
                ->groupBy('a.dilgrup')
                ->orderBy('d.id')
                ->getQuery()
                ->getScalarResult();

            if (!empty($ayarBul)) {
                $sayfaSecim = $em->getReference(Sayfa::class, $ayarBul[0]['s_id']);
                foreach ($ayarBul as $aB) {
                    if (empty($aB['a_keywords'])) {
                        $aB['a_keywords'] = null;
                    } else {
                        $aB['a_keywords'] = $this->ceviri($aB['a_keywords'], $id);
                    }
                    if (empty($aB['a_description'])) {
                        $aB['a_description'] = null;
                    } else {
                        $aB['a_description'] = $this->ceviri($aB['a_description'], $id);
                    }


                    $x = new Kategori();
                    $x->setDil($dilSecim);
                    $x->setDilgrup($aB['a_dilgrup']);
                    $x->setSeourl($this->seo($this->ceviri($aB['a_adi'], $id)));
                    $x->setTitle($this->ceviri($aB['a_title'], $id));
                    $x->setKeywords($aB['a_keywords']);
                    $x->setDescription($aB['a_description']);
                    $x->setAdi($this->ceviri($aB['a_adi'], $id));
                    $x->setUstid($aB['a_ustid']);
                    $x->setResim($aB['a_resim']);
                    $x->setSira($aB['a_sira']);
                    $x->setSayfa($sayfaSecim);
                    $em->persist($x);
                    $em->flush();
                }
            }


            //Sayfa Güncelleme
            $qb = $em->createQueryBuilder();
            $sayfaBul=$qb->select('s.id,s.icIcerik,s.adi,s.bannerDurum,s.bannerUrl,s.title,s.seo,s.keywords,s.description,d.kisa as dKisa,m.id as mid,s.dilgrup,s.menu,s.kategori,s.tekVeri,s.anasayfa,s.footer,m.alan,m.tip,m.bosluk,m.cokluDil,m.tabloAdi,m.adi as madi')
                ->from('App:Sayfa', 's')
                ->join('s.dil','d')
                ->join('s.modul','m')
                ->where("d.id = $gecerliDil")
                ->groupby('s.dilgrup')
                ->orderBy('d.id')
                ->getQuery()
                ->getScalarResult();
            foreach ($sayfaBul as $sB){
                $modul = $em->getReference(Modul::class,$sB['mid']);


                if (empty($sB['keywords'])) {
                    $sB['keywords'] = null;
                } else {
                    $sB['keywords'] = $this->ceviri($sB['keywords'], $id);
                }


                if (empty($sB['description'])) {
                    $sB['description'] = null;
                } else {
                    $sB['description'] = $this->ceviri($sB['description'], $id);
                }


                $sayfaAdi = $this->ceviri($sB['adi'],$id);


                $sayfa = new Sayfa();
                $sayfa->setAdi($sayfaAdi);
                $sayfa->setBannerDurum($sB['bannerDurum']);
                $sayfa->setBannerUrl($sB['bannerUrl']);
                $sayfa->setTitle($this->ceviri($sB['title'],$id));
                $sayfa->setSeo($this->seo($sayfaAdi,$id));
                $sayfa->setKeywords($sB['keywords']);
                $sayfa->setDescription($sB['description']);
                $sayfa->setDilgrup($sB['dilgrup']);
                $sayfa->setDil($dilSecim);
                $sayfa->setModul($modul);
                $sayfa->setSira(0);
                $sayfa->setMenu($sB['menu']);
                $sayfa->setKategori($sB['kategori']);
                $sayfa->setTekVeri($sB['tekVeri']);
                $sayfa->setIcIcerik($sB['icIcerik']);
                $sayfa->setAnasayfa($sB['anasayfa']);
                $sayfa->setFooter($sB['footer']);
                $em->persist($sayfa);
                $em->flush();




                // İçerik Güncelleme
                if ($sB['tekVeri'] == 1) {

                    $alanlarim = [];
                    $alanlar = explode(',',$sB['alan']);
                    $tipler = explode(',',$sB['tip']);

                    foreach ($tipler as $key=>$tip) {
                        $alanlarim[] = 't.'.$this->seo(str_replace(' ', '', $alanlar[$key]));
                    }
                    $alann = implode(',',$alanlarim);


                    $qb = $em->createQueryBuilder();
                    $veriler=$qb->select($alann.',t.dilgrup,d.kisa as dKisa,k.id as kategoriId')
                        ->from('App:'.$sB['tabloAdi'], 't')
                        ->join('t.dil','d')
                        ->join('t.sayfa','s')
                        ->leftjoin('t.kategori','k')
                        ->where('s.id='.$sB['id'])
                        ->groupBy('t.dilgrup')
                        ->getQuery()
                        ->getScalarResult();






                    $icDilgrup = $veriler[0]['dilgrup'];
                    $sayfaId = $sB['id'];
                    $kategoriId = $veriler[0]['kategoriId'];
                    if (empty($veriler[0]['kategoriId'])) {
                        $kategoriId = 'NULL';
                    }


                    $veri = [];
                    $alan = [];
                    foreach ($tipler as $key => $tip) {
                        $alan[] = $this->seo(str_replace(' ', '', $alanlar[$key]));

                        if ($this->seo($alanlar[$key]) == 'resim') {
                            $veri[] = "'" . $veriler[0][$this->seo(str_replace(' ', '', $alanlar[$key]))] . "'";
                        } elseif ($this->seo($alanlar[$key]) == 'resimler') {
                            $veri[] = "'" . $veriler[0][$this->seo(str_replace(' ', '', $alanlar[$key]))] . "'";
                        } elseif ($this->seo($alanlar[$key]) == 'seo-url') {
                            $veri[] = "'" . $this->seo($this->ceviri($veriler[0][$this->seo(str_replace(' ', '', $alanlar[$key]))] ,  $id),  $id)."'";

                        } else {

                            if ($tip == 'string') {
                                $veri[] = "'" . htmlentities($this->ceviri($veriler[0][$this->seo(str_replace(' ', '', $alanlar[$key]))],  $id), ENT_QUOTES, "UTF-8") . "'";
                            } elseif ($tip == 'text') {
                                $veri[] = "'" . htmlentities($veriler[0][$this->seo(str_replace(' ', '', $alanlar[$key]))], ENT_QUOTES, "UTF-8") . "'";
                            } else {
                                $veri[] = "'" . htmlentities($veriler[0][$this->seo(str_replace(' ', '', $alanlar[$key]))], ENT_QUOTES, "UTF-8") . "'";
                            }


                        }
                    }
                    $veri = implode(',', $veri);
                    $alan = implode(',', $alan);


                    $RAW_QUERY = "INSERT INTO " . $this->seo(str_replace(' ', '', $sB['madi'])) . "(dil_id,dilgrup,sayfa_id,kategori_id,sira," . $alan . ") VALUES($id,$icDilgrup,$sayfaId,$kategoriId,NULL,$veri)";

                    $statement = $em->getConnection()->prepare($RAW_QUERY);
                    $statement->execute();


                }
                else {

                    $alanlarim = [];
                    $alanlar = explode(',',$sB['alan']);
                    $tipler = explode(',',$sB['tip']);

                    foreach ($tipler as $key=>$tip) {
                        $alanlarim[] = 't.'.$this->seo(str_replace(' ', '', $alanlar[$key]));
                    }
                    $alann = implode(',',$alanlarim);


                    $qb = $em->createQueryBuilder();
                    $veriler=$qb->select($alann.',t.dilgrup,d.kisa as dKisa,k.id as kategoriId')
                        ->from('App:'.$sB['tabloAdi'], 't')
                        ->join('t.dil','d')
                        ->join('t.sayfa','s')
                        ->leftjoin('t.kategori','k')
                        ->where('s.id='.$sB['id'])
                        ->groupBy('t.dilgrup')
                        ->getQuery()
                        ->getScalarResult();

                    foreach ($veriler as $vv){


                        $icDilgrup = $vv['dilgrup'];
                        $sayfaId = $sB['id'];
                        $kategoriId = $vv['kategoriId'];
                        if(empty($vv['kategoriId'])){
                            $kategoriId  = 'NULL';
                        }



                        $veri = [];
                        $alan = [];
                        foreach ($tipler as $key=>$tip){
                            $alan[]=$this->seo(str_replace(' ','',$alanlar[$key]));

                            if($this->seo($alanlar[$key])=='resim'){
                                $veri[] = "'".$vv[$this->seo(str_replace(' ','',$alanlar[$key]))]."'";
                            }
                            elseif ($this->seo($alanlar[$key])=='resimler'){
                                $veri[] = "'".$vv[$this->seo(str_replace(' ','',$alanlar[$key]))]."'";
                            }
                            elseif ($this->seo($alanlar[$key])=='seo-url'){
                                $veri[]="'".$this->seo($this->ceviri($vv[$this->seo(str_replace(' ','',$alanlar[$key]))],$id),$id)."'";

                            }else{

                                if($tip=='string'){
                                    $veri[] = "'".htmlentities($this->ceviri($vv[$this->seo(str_replace(' ','',$alanlar[$key]))],$id),ENT_QUOTES, "UTF-8")."'";
                                }elseif($tip=='text'){
                                    $veri[] = "'".htmlentities($vv[$this->seo(str_replace(' ','',$alanlar[$key]))],ENT_QUOTES, "UTF-8")."'";
                                }else{
                                    $veri[] = "'".htmlentities($vv[$this->seo(str_replace(' ','',$alanlar[$key]))],ENT_QUOTES, "UTF-8")."'";
                                }


                            }
                        }
                        $veri = implode(',',$veri);
                        $alan = implode(',',$alan);


                        $RAW_QUERY = "INSERT INTO ".$this->seo(str_replace(' ','',$sB['madi']))."(dil_id,dilgrup,sayfa_id,kategori_id,sira,".$alan.") VALUES($id,$icDilgrup,$sayfaId,$kategoriId,NULL,$veri)";

                        $statement = $em->getConnection()->prepare($RAW_QUERY);
                        $statement->execute();


                    }



                }



            }


            $dil = $em->getRepository(Dil::class)->find($id);
            $dil->setAktif(1);
            $em->persist($dil);
            $em->flush();




        }
        else {

            $qb = $em->createQueryBuilder();
            $dilVeri=$qb->select('d.id,d.kisa,d.uzun,d.aktif')
                ->from('App:Dil', 'd')
                ->where('d.id='.$id)
                ->getQuery()
                ->getScalarResult();

            $dd = $em->getRepository(Dil::class)->find($id);
            $em->remove($dd);
            $em->flush();

            $dd = new Dil();
            $dd->setAktif(0);
            $dd->setVarsayilan(0);
            $dd->setKisa($dilVeri[0]['kisa']);
            $dd->setUzun($dilVeri[0]['uzun']);
            $em->persist($dd);
            $em->flush();





            $dilSon = $em->getRepository(Dil::class)->find($dd->getId());
            $qb = $em->createQueryBuilder();
            $q = $qb->update('App:Dil', 'd')
                ->set('d.id', ':id')
                ->where("d.id = ".$dilSon->getId())
                ->setParameter('id', $id)
                ->getQuery()
                ->execute();




        }

        $em->flush();




        if ($this->dilSay()>1){
            $dosya = fopen($_SERVER['DOCUMENT_ROOT'] . '/public/stokSDC_D.php', 'r');
            $icerik = fread($dosya, filesize($_SERVER['DOCUMENT_ROOT'] . '/public/stokSDC_D.php'));

            $dosya2 = fopen($_SERVER['DOCUMENT_ROOT'] . '/src/Controller/SiteDefaultController.php', 'w');
            fwrite($dosya2, $icerik);
            fclose($dosya2);
        }else{
            $dosya = fopen($_SERVER['DOCUMENT_ROOT'] . '/public/stokSDC.php', 'r');
            $icerik = fread($dosya, filesize($_SERVER['DOCUMENT_ROOT'] . '/public/stokSDC.php'));

            $dosya2 = fopen($_SERVER['DOCUMENT_ROOT'] . '/src/Controller/SiteDefaultController.php', 'w');
            fwrite($dosya2, $icerik);
            fclose($dosya2);
        }










        // $dosyaadi = $_SERVER['DOCUMENT_ROOT'].'/app/config/routing.yml';
        // if ($this->dilSay()>1){
        /*       $veri = '# app/config/routing.yml
   fos_user:
       resource: "@FOSUserBundle/Resources/config/routing/all.xml"

   panel:
       resource: "panelBundle/Resources/config/anasayfa.yml"
       prefix:   /seven/

   giris:
       resource: "@SiteBundle/Resources/config/giris.yml"
       prefix:   /
   ';
               $dosya = fopen($dosyaadi, 'w');
               fwrite($dosya, $veri);
               fclose($dosya);*/

        //   }else{
        /*  $veri = '# app/config/routing.yml
fos_user:
  resource: "@FOSUserBundle/Resources/config/routing/all.xml"

panel:
  resource: "panelBundle/Resources/config/anasayfa.yml"
  prefix:   /seven/

site:
  resource: "@SiteBundle/Resources/config/site.yml"
  prefix:   /
';
          $dosya = fopen($dosyaadi, 'w');
          fwrite($dosya, $veri);
          fclose($dosya);*/

        //   }



        return new Response('');

    }

    /**
     * @Route("/rv/dil/varsayilan", name="dil_varsayilan")
     */
    public function varsayilan(Request $request): Response{
        $em = $this->getDoctrine()->getManager();

        $id = $request->request->get('id');

        $qb = $em->createQueryBuilder();
        $q = $qb->update('App:Dil', 'd')
            ->set('d.varsayilan', 0)
            ->getQuery()
            ->execute();

        $qb = $em->createQueryBuilder();
        $q = $qb->update('App:Dil', 'd')
            ->set('d.varsayilan', 1)
            ->where("d.id = $id")
            ->getQuery()
            ->execute();

        return new Response('');

    }

}
