<?php

namespace App\Controller;

use App\Entity\User;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Mime\Address;
use Symfony\Component\Routing\Annotation\Route;
use App\Controller\BaseController;
use Symfony\Component\Security\Core\Encoder\UserPasswordEncoderInterface;
use Symfony\Component\Mime\Email;
use Symfony\Component\Mailer\MailerInterface;

class PanelKullanicilarController extends BaseController
{
    /**
     * @Route("/rv/kullanicilar", name="kullanicilar_homepage")
     */
    public function index(): Response
    {
        return $this->render('panel/kullanicilar/index.html.twig');
    }

    /**
     * @Route("/rv/kullanicilar/getir", name="kullanicilar_getir")
     */
    public function getir(): Response
    {
        $em = $this->getDoctrine()->getManager();

        $qb = $em->createQueryBuilder();
        $kullanicilar=$qb->select('k.id,k.email,k.adsoyad,k.unvan')
            ->from('App:User', 'k')
            ->where("(k.roles like '%ROLE_ADMIN%' or k.roles like '%ROLE_KULLANICI%') and k.id not in(".$this->getUser()->getId().")")
            ->getQuery()
            ->getScalarResult();

        return $this->render('panel/kullanicilar/getir.html.twig',array('kullanicilar'=>$kullanicilar));

    }

    /**
     * @Route("/rv/kullanicilar/ekle", name="kullanicilar_ekle")
     */
    public function ekle(Request $request, UserPasswordEncoderInterface $passwordEncoder, MailerInterface $mailer): Response
    {
        $em = $this->getDoctrine()->getManager();

        $eposta = $request->request->get('eposta');
        $sifre = $this->rasgele(8);
        $adsoyad = $request->request->get('adsoyad');if(empty($adsoyad)){$adsoyad=null;}
        $unvan = $request->request->get('unvan');if(empty($unvan)){$unvan=null;}


        $qb=$em->createQueryBuilder();
        $kullaniciTara=$qb->select('k.id')
            ->from('App:User', 'k')
            ->where("k.email='".$eposta."'")
            ->getQuery()
            ->getScalarResult();

        if(count($kullaniciTara)>0){
            return new Response('E-Posta adresi başkası tarafından kullanılıyor.');
        }else{
            $user = new User();
            $user->setAdsoyad($adsoyad);
            $user->setUnvan($unvan);
            $user->setEmail($eposta);
            $user->setIsVerified(1);
            $user->setIsPassword(0);
            $user->setPassword($passwordEncoder->encodePassword($user, $sifre));
            if ($this->getUser()->getRoles()[0]=='ROLE_DEV'){
                $user->setRoles(array("ROLE_ADMIN"));
            }else{
                $user->setRoles(array("ROLE_KULLANICI"));
            }
            $em->persist($user);
            $em->flush();



            $email = (new Email())
                ->from(new Address($this->ayarlar('sistemPosta'),$this->ayarlar('siteAdi')))
                ->to(new Address($eposta,$adsoyad))
                //->cc('cc@example.com')
                //->bcc('bcc@example.com')
                //->replyTo('fabien@example.com')
                ->priority(Email::PRIORITY_HIGH)
                ->subject($this->ceviri('Yönetim paneli giriş hesabın oluşturuldu.').' - '.$this->ayarlar('siteAdi'))
                //->text('Sending emails is fun again!')
                ->html($this->renderView('mail/yenikullanici_mail.html.twig',array('eposta'=>$eposta,'sifre'=>$sifre,'adsoyad'=>$adsoyad,'unvan'=>$unvan)));
            $mailer->send($email);

        }


        return new Response('');
    }

    /**
     * @Route("/rv/kullanicilar/duzenleAc", name="kullanicilar_duzenleAc")
     */
    public function duzenleAc(Request $request): Response
    {
        $em = $this->getDoctrine()->getManager();

        $id = $request->request->get('id');
        $qb = $em->createQueryBuilder();
        $kullanici=$qb->select('k.id,k.email,k.adsoyad,k.unvan')
            ->from('App:User', 'k')
            ->where("k.id=$id")
            ->getQuery()
            ->getScalarResult();




        return $this->render('panel/kullanicilar/duzenleAc.html.twig',array('kullanici'=>$kullanici[0]));
    }

    /**
     * @Route("/rv/kullanicilar/duzenle", name="kullanicilar_duzenle")
     */
    public function duzenle(Request $request, UserPasswordEncoderInterface $passwordEncoder, MailerInterface $mailer): Response
    {
        $em = $this->getDoctrine()->getManager();

        $id = $request->request->get('id');
        $eposta = $request->request->get('eposta');
        $sifre = $request->request->get('sifre');
        $adsoyad = $request->request->get('adsoyad');if(empty($adsoyad)){$adsoyad=null;}
        $unvan = $request->request->get('unvan');if(empty($unvan)){$unvan=null;}

        $qb=$em->createQueryBuilder();
        $kullaniciTara=$qb->select('k.id')
            ->from('App:User', 'k')
            ->where("k.email='".$eposta."' and k.id not in($id)")
            ->getQuery()
            ->getScalarResult();

        if(count($kullaniciTara)>0){
            return new Response('E-Posta adresi başkası tarafından kullanılıyor.');
        }else{
            $user = $em->getRepository(User::class)->findOneBy(array('id' => $id));

            $user->setAdsoyad($adsoyad);
            $user->setUnvan($unvan);
            $user->setEmail($eposta);
            if (!empty($sifre)) {
                $user->setPassword($passwordEncoder->encodePassword($user, $sifre));
            }
            $em->persist($user);
            $em->flush();
        }



        $email = (new Email())
            ->from(new Address($this->ayarlar('sistemPosta'),$this->ayarlar('siteAdi')))
            ->to(new Address($eposta,$adsoyad))
            //->cc('cc@example.com')
            //->bcc('bcc@example.com')
            //->replyTo('fabien@example.com')
            ->priority(Email::PRIORITY_HIGH)
            ->subject($this->ceviri('Yönetim paneli giriş hesabın değiştirildi.').' - '.$this->ayarlar('siteAdi'))
            //->text('Sending emails is fun again!')
            ->html($this->renderView('mail/kullaniciduzenle_mail.html.twig',array('eposta'=>$eposta,'sifre'=>$sifre,'adsoyad'=>$adsoyad,'unvan'=>$unvan)));
        $mailer->send($email);




        return new Response('');
    }

    /**
     * @Route("/rv/kullanicilar/sil", name="kullanicilar_sil")
     */
    public function sil(Request $request): Response
    {
        $em = $this->getDoctrine()->getManager();

        $id = $request->request->get('id');

        $kk = $em->getRepository(User::class)->findOneBy(array('id'=>$id));
        $em->remove($kk);
        $em->flush();

        return new Response('');
    }

}
