<?php

namespace App\Controller;

use App\Entity\Dil;
use App\Entity\Modul;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use App\Controller\BaseController;
use App\Entity\Sayfa;

class PanelSayfaController extends BaseController
{
    /**
     * @Route("/rv/sayfa", name="sayfa_homepage")
     */
    public function index(): Response
    {

        $em = $this->getDoctrine()->getManager();
        $qb = $em->createQueryBuilder();
        $diller=$qb->select('d.id,d.kisa')
            ->from('App:Dil', 'd')
            ->where("d.aktif=1")
            ->orderBy('d.id')
            ->getQuery()
            ->getScalarResult();

        $qb = $em->createQueryBuilder();
        $moduller=$qb->select('m.adi,m.id')
            ->from('App:Modul', 'm')
            ->getQuery()
            ->getScalarResult();

        return $this->render('panel/sayfa/index.html.twig',array('diller'=>$diller,'moduller'=>$moduller));
    }

    /**
     * @Route("/rv/sayfa/getir", name="sayfa_getir")
     */
    public function getir(): Response{
        $em = $this->getDoctrine()->getManager();

        $qb = $em->createQueryBuilder();
        $sayfalar=$qb->select('s.id,s.adi,s.bannerDurum,s.bannerUrl,s.title,s.keywords,s.description,s.dilgrup,d.kisa as dKisa,m.adi as modul,s.seo,s.menu,s.kategori,s.tekVeri,s.resimBoyut,s.anasayfa,s.footer,s.icIcerik')
            ->from('App:Sayfa', 's')
            ->join('s.dil', 'd')
            ->join('s.modul', 'm')
            ->orderBy('s.sira','ASC')
            ->groupBy('s.dilgrup')
            ->getQuery()
            ->getScalarResult();

        return $this->render('panel/sayfa/getir.html.twig',array('sayfalar'=>$sayfalar));
    }

    /**
     * @Route("/rv/sayfa/ekle", name="sayfa_ekle")
     */
    public function ekle(Request $request): Response
    {
        $em = $this->getDoctrine()->getManager();

        $adi = $request->request->get('adi');
        $modul = $request->request->get('modul');  $modul = $em->getReference(Modul::class,$modul);
        $banner = $request->request->get('banner');
        $menu = $request->request->get('menu');
        $anasayfa = $request->request->get('anasayfa');
        $kategori = $request->request->get('kategori');
        $tekveri = $request->request->get('tekveri');
        $icicerik = $request->request->get('icicerik');
        $resimBoyut = $request->request->get('resimBoyut'); if (empty($resimBoyut)){ $resimBoyut=null; }


        if($banner==1){
            $bannerResim=$this->seo($adi[0]).'_banner_'.time().'_';
            move_uploaded_file($_FILES['bannerresim']['tmp_name'], "gecici_yukleme/".$bannerResim.$this->uzantiBul($_FILES['bannerresim']['type']));
            $bannerResim = $this->imageResizer($bannerResim.$this->uzantiBul($_FILES['bannerresim']['type']),$bannerResim);
            $this->uploadFile($bannerResim);
        }else{
            $bannerResim=null;
        }

        $qb = $em->createQueryBuilder();
        $diller=$qb->select('d.id')
            ->from('App:Dil', 'd')
            ->where("d.aktif=1")
            ->orderBy('d.id')
            ->getQuery()
            ->getScalarResult();
  
        $son_dilgrup = $this->son_dilgrup('Sayfa');
        foreach ($diller as $key=>$dil){
            $dilSecim = $em->getReference(Dil::class,$dil['id']);

            $sayfa = new Sayfa();
            $sayfa->setAdi($adi[$key]);
            $sayfa->setDil($dilSecim);
            $sayfa->setDilgrup($son_dilgrup);
            $sayfa->setSeo($this->seo($adi[$key]));
            $sayfa->setModul($modul);
            $sayfa->setBannerDurum($banner);
            $sayfa->setBannerUrl($bannerResim);
            $sayfa->setTitle($adi[$key]);
            $sayfa->setSira(0);
            $sayfa->setMenu($menu);
            $sayfa->setFooter(0);
            $sayfa->setAnasayfa($anasayfa);
            $sayfa->setKategori($kategori);
            $sayfa->setTekVeri($tekveri);
            $sayfa->setIcIcerik($icicerik);
            $sayfa->setResimBoyut($resimBoyut);
            $em->persist($sayfa);

        }


        $em->flush();
        return new Response('');
    }

    /**
     * @Route("/rv/sayfa/duzenleAc", name="sayfa_duzenleAc")
     */
    public function duzenleAc(Request $request): Response{
        $em = $this->getDoctrine()->getManager();

        $id = $request->request->get('id');
        $qb = $em->createQueryBuilder();
        $sayfa=$qb->select('s.id,s.dilgrup,s.adi,s.bannerDurum,s.bannerUrl,s.menu,s.kategori,s.tekVeri,s.icIcerik,s.resimBoyut,s.anasayfa')
            ->from('App:Sayfa', 's')
            ->where("s.dilgrup=$id")
            ->orderBy('s.dil')
            ->getQuery()
            ->getScalarResult();


        $qb = $em->createQueryBuilder();
        $diller=$qb->select('d.id,d.kisa')
            ->from('App:Dil', 'd')
            ->where("d.aktif=1")
            ->orderBy('d.id')
            ->getQuery()
            ->getScalarResult();

        return $this->render('panel/sayfa/duzenleAc.html.twig',array('sayfa'=>$sayfa,'diller'=>$diller));
    }

    /**
     * @Route("/rv/sayfa/duzenle", name="sayfa_duzenle")
     */
    public function duzenle(Request $request): Response
    {
        $em = $this->getDoctrine()->getManager();

        $dilgrup = $request->request->get('id');
        $adi = $request->request->get('adi');
        $bannerUrl = $request->request->get('bannerUrl');
        $resimBoyut = $request->request->get('resimBoyut'); if(empty($resimBoyut)){$resimBoyut=null;}

        $banner = $request->request->get('banner');
        $menu = $request->request->get('menu');
        $anasayfa = $request->request->get('anasayfa');
        $kategori = $request->request->get('kategori');
        $tekveri = $request->request->get('tekveri');
        $icicerik = $request->request->get('icicerik');

        $qb = $em->createQueryBuilder();
        $sayfaBul=$qb->select('m.id as mid')
            ->from('App:Sayfa', 's')
            ->join('s.modul','m')
            ->where('s.dilgrup='.$dilgrup)
            ->getQuery()
            ->getScalarResult();
        $modul = $em->getReference(Modul::class,$sayfaBul[0]['mid']);


        if($banner==1){
            if (!empty($_FILES['bannerresim']['name'])) {
                $bannerResim = $this->seo($adi[0]) . '_banner_' . time() . '_';
                move_uploaded_file($_FILES['bannerresim']['tmp_name'], "gecici_yukleme/" . $bannerResim . $this->uzantiBul($_FILES['bannerresim']['type']));
                $bannerResim = $this->imageResizer($bannerResim . $this->uzantiBul($_FILES['bannerresim']['type']),$bannerResim);
                $this->uploadFile($bannerResim);
               //@unlink('uploads/'.$bannerUrl);
                $this->deleteFile($bannerUrl);
            }else{
                $bannerResim = $bannerUrl;
            }
        }else{
            $bannerResim=null;
            //@unlink('uploads/'.$bannerUrl);
            $this->deleteFile($bannerUrl);
        }






        $qb = $em->createQueryBuilder();
        $diller=$qb->select('d.id')
            ->from('App:Dil', 'd')
            ->where("d.aktif=1")
            ->orderBy('d.id')
            ->getQuery()
            ->getScalarResult();


        foreach ($diller as $key=>$dil){
            $dilSecim = $em->getReference(Dil::class,$dil['id']);



            $qb = $em->createQueryBuilder();
            $q = $qb->update('App:Sayfa', 's')
                ->set('s.adi', ':adi')
                ->set('s.dil', ':dil')
                ->set('s.dilgrup', ':dilgrup')
                ->set('s.modul', ':modul')
                ->set('s.bannerDurum', ':bannerDurum')
                ->set('s.bannerUrl', ':bannerUrl')
                ->set('s.menu', ':menu')
                ->set('s.anasayfa', ':anasayfa')
                ->set('s.kategori', ':kategori')
                ->set('s.tekVeri', ':tekVeri')
                ->set('s.icIcerik', ':icIcerik')
                ->set('s.resimBoyut', ':resimBoyut')
                ->where("s.dil = ".$dil['id']." and s.dilgrup=$dilgrup")
                ->setParameter('adi', $adi[$key])
                ->setParameter('dil', $dilSecim)
                ->setParameter('dilgrup', $dilgrup)
                ->setParameter('modul', $modul)
                ->setParameter('bannerDurum', $banner)
                ->setParameter('bannerUrl', $bannerResim)
                ->setParameter('menu', $menu)
                ->setParameter('anasayfa', $anasayfa)
                ->setParameter('kategori', $kategori)
                ->setParameter('tekVeri', $tekveri)
                ->setParameter('icIcerik', $icicerik)
                ->setParameter('resimBoyut', $resimBoyut)
                ->getQuery()
                ->execute();



        }





        return new Response('');
    }

    /**
     * @Route("/rv/sayfa/sil", name="sayfa_sil")
     */
    public function sil(Request $request): Response{
        $em = $this->getDoctrine()->getManager();

        $id = $request->request->get('id');

        $qb = $em->createQueryBuilder();
        $sayfaBul=$qb->select('m.tabloAdi,m.alan,s.bannerUrl')
            ->from('App:Sayfa', 's')
            ->join('s.modul','m')
            ->where('s.dilgrup='.$id)
            ->getQuery()
            ->getScalarResult();



        if (!empty($sayfaBul[0]['bannerUrl'])){
            //@unlink('uploads/'.$sayfaBul[0]['bannerUrl']);
            $this->deleteFile($sayfaBul[0]['bannerUrl']);
        }




        $sss = $em->getRepository(Sayfa::class)->findBy(array('dilgrup'=>$id));
        $this->removeEntity($sss);
        $em->flush();


        return new Response('');
    }

    /**
     * @Route("/rv/sayfa/seoAyarAc", name="sayfa_seoAyarAc")
     */
    public function seoAyarAc(Request $request): Response{
        $em = $this->getDoctrine()->getManager();

        $id = $request->request->get('id');
        $qb = $em->createQueryBuilder();
        $sayfa=$qb->select('s.id,s.dilgrup,s.seo,s.title,s.keywords,s.description')
            ->from('App:Sayfa', 's')
            ->where("s.dilgrup=$id")
            ->orderBy('s.dil')
            ->getQuery()
            ->getScalarResult();


        $qb = $em->createQueryBuilder();
        $diller=$qb->select('d.id,d.kisa')
            ->from('App:Dil', 'd')
            ->where("d.aktif=1")
            ->orderBy('d.id')
            ->getQuery()
            ->getScalarResult();

        return $this->render('panel/sayfa/seoAyarAc.html.twig',array('sayfa'=>$sayfa,'diller'=>$diller));
    }

    /**
     * @Route("/rv/sayfa/seoAyar", name="sayfa_seoAyar")
     */
    public function seoAyar(Request $request): Response
    {
        $em = $this->getDoctrine()->getManager();

        $dilgrup = $request->request->get('id');
        $seourl = $request->request->get('seourl');
        $title = $request->request->get('title');
        $keywords = $request->request->get('keywords');
        $description = $request->request->get('description');


        $qb = $em->createQueryBuilder();
        $diller=$qb->select('d.id')
            ->from('App:Dil', 'd')
            ->where("d.aktif=1")
            ->orderBy('d.id')
            ->getQuery()
            ->getScalarResult();


        foreach ($diller as $key=>$dil){


            $qb = $em->createQueryBuilder();
            $q = $qb->update('App:Sayfa', 's')
                ->set('s.seo', ':seo')
                ->set('s.title', ':title')
                ->set('s.keywords', ':keywords')
                ->set('s.description', ':description')
                ->where("s.dil = ".$dil['id']." and s.dilgrup=$dilgrup")
                ->setParameter('seo', $this->seo($seourl[$key],$dil['id']))
                ->setParameter('title', $title[$key])
                ->setParameter('keywords', $keywords[$key])
                ->setParameter('description', $description[$key])
                ->getQuery()
                ->execute();


        }




        return new Response('');
    }

    /**
     * @Route("/rv/sayfa/sirala", name="sayfa_sirala")
     */
    public function sirala(Request $request): Response
    {
        $em = $this->getDoctrine()->getManager();
        $listItem = $request->request->get('listItem');

        foreach ($listItem as $sira=>$id){
            $qb = $em->createQueryBuilder();
            $q = $qb->update('App:Sayfa', 's')
                ->set('s.sira', ':sira')
                ->where("s.dilgrup=$id")
                ->setParameter('sira', $sira)
                ->getQuery()
                ->execute();
        }

        return new Response('');
    }



    /**
     * @Route("/rv/sayfa/footer", name="sayfa_footer")
     */
    public function footer(Request $request): Response
    {
        $em = $this->getDoctrine()->getManager();

        $dilgrup = $request->request->get('id');



        $qb = $em->createQueryBuilder();
        $q = $qb->update('App:Sayfa', 's')
            ->set('s.footer', ':footer')
            ->setParameter('footer', 0)
            ->getQuery()
            ->execute();

        $qb = $em->createQueryBuilder();
        $q = $qb->update('App:Sayfa', 's')
            ->set('s.footer', ':footer')
            ->where("s.dilgrup=$dilgrup")
            ->setParameter('footer', 1)
            ->getQuery()
            ->execute();







        return new Response('');
    }

}


