<?php

namespace App\Entity;

use App\Repository\KategoriRepository;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;

/**
 * @ORM\Entity(repositoryClass=KategoriRepository::class)
 */
class Kategori
{
    /**
     * @ORM\Id
     * @ORM\GeneratedValue
     * @ORM\Column(type="integer")
     */
    private $id;

    /**
     * @ORM\Column(type="string", length=255)
     */
    private $seourl;

    /**
     * @ORM\Column(type="string", length=255)
     */
    private $title;

    /**
     * @ORM\Column(type="text", nullable=true)
     */
    private $keywords;

    /**
     * @ORM\Column(type="text", nullable=true)
     */
    private $description;

    /**
     * @ORM\Column(type="string", length=255)
     */
    private $adi;

    /**
     * @ORM\Column(type="integer")
     */
    private $ustid;

    /**
     * @ORM\Column(type="string", length=255, nullable=true)
     */
    private $resim;

    /**
     * @ORM\Column(type="integer")
     */
    private $dilgrup;

    /**
     * @ORM\Column(type="integer")
     */
    private $sira;

    /**
     * @ORM\ManyToOne(targetEntity=Sayfa::class, inversedBy="kat")
     * @ORM\JoinColumn(nullable=false)
     */
    private $sayfa;

    /**
     * @ORM\ManyToOne(targetEntity=Dil::class, inversedBy="kategori")
     * @ORM\JoinColumn(nullable=false)
     */
    private $dil;

    /**
     * @ORM\OneToMany(targetEntity=Kurumsal::class, mappedBy="kategori", orphanRemoval=true)
     */
    private $kurumsal;

    /**
     * @ORM\OneToMany(targetEntity=Iletisim::class, mappedBy="kategori", orphanRemoval=true)
     */
    private $iletisim;

    /**
     * @ORM\OneToMany(targetEntity=Hizmetler::class, mappedBy="kategori", orphanRemoval=true)
     */
    private $hizmetler;

    /**
     * @ORM\OneToMany(targetEntity=Footermetin::class, mappedBy="kategori", orphanRemoval=true)
     */
    private $footermetin;

    /**
     * @ORM\OneToMany(targetEntity=Bossayfa::class, mappedBy="kategori", orphanRemoval=true)
     */
    private $bossayfa;

    /**
     * @ORM\OneToMany(targetEntity=Haberler::class, mappedBy="kategori", orphanRemoval=true)
     */
    private $haberler;

    public function __construct()
    {
       $this->kurumsal = new ArrayCollection();
       $this->iletisim = new ArrayCollection();
       $this->hizmetler = new ArrayCollection();
       $this->footermetin = new ArrayCollection();
       $this->bossayfa = new ArrayCollection();
       $this->haberler = new ArrayCollection();

    }

    public function getId(): ?int
    {
        return $this->id;
    }

    /**
     * @return Collection|Kurumsal[]
     */
    public function getKurumsal(): Collection
    {
        return $this->kurumsal;
    }
    
    public function addKurumsal(Kurumsal $kurumsal): self
    {
        if (!$this->kurumsal->contains($kurumsal)) {
            $this->kurumsal[] = $kurumsal;
            $kurumsal->setKategori($this);
        }

        return $this;
    }

    public function removeKurumsal(Kurumsal $kurumsal): self
    {
        if ($this->kurumsal->removeElement($kurumsal)) {
            // set the owning side to null (unless already changed)
            if ($kurumsal->getKategori() === $this) {
                $kurumsal->setKategori(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|Iletisim[]
     */
    public function getIletisim(): Collection
    {
        return $this->iletisim;
    }
    
    public function addIletisim(Iletisim $iletisim): self
    {
        if (!$this->iletisim->contains($iletisim)) {
            $this->iletisim[] = $iletisim;
            $iletisim->setKategori($this);
        }

        return $this;
    }

    public function removeIletisim(Iletisim $iletisim): self
    {
        if ($this->iletisim->removeElement($iletisim)) {
            // set the owning side to null (unless already changed)
            if ($iletisim->getKategori() === $this) {
                $iletisim->setKategori(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|Hizmetler[]
     */
    public function getHizmetler(): Collection
    {
        return $this->hizmetler;
    }
    
    public function addHizmetler(Hizmetler $hizmetler): self
    {
        if (!$this->hizmetler->contains($hizmetler)) {
            $this->hizmetler[] = $hizmetler;
            $hizmetler->setKategori($this);
        }

        return $this;
    }

    public function removeHizmetler(Hizmetler $hizmetler): self
    {
        if ($this->hizmetler->removeElement($hizmetler)) {
            // set the owning side to null (unless already changed)
            if ($hizmetler->getKategori() === $this) {
                $hizmetler->setKategori(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|Footermetin[]
     */
    public function getFootermetin(): Collection
    {
        return $this->footermetin;
    }
    
    public function addFootermetin(Footermetin $footermetin): self
    {
        if (!$this->footermetin->contains($footermetin)) {
            $this->footermetin[] = $footermetin;
            $footermetin->setKategori($this);
        }

        return $this;
    }

    public function removeFootermetin(Footermetin $footermetin): self
    {
        if ($this->footermetin->removeElement($footermetin)) {
            // set the owning side to null (unless already changed)
            if ($footermetin->getKategori() === $this) {
                $footermetin->setKategori(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|Bossayfa[]
     */
    public function getBossayfa(): Collection
    {
        return $this->bossayfa;
    }
    
    public function addBossayfa(Bossayfa $bossayfa): self
    {
        if (!$this->bossayfa->contains($bossayfa)) {
            $this->bossayfa[] = $bossayfa;
            $bossayfa->setKategori($this);
        }

        return $this;
    }

    public function removeBossayfa(Bossayfa $bossayfa): self
    {
        if ($this->bossayfa->removeElement($bossayfa)) {
            // set the owning side to null (unless already changed)
            if ($bossayfa->getKategori() === $this) {
                $bossayfa->setKategori(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|Haberler[]
     */
    public function getHaberler(): Collection
    {
        return $this->haberler;
    }
    
    public function addHaberler(Haberler $haberler): self
    {
        if (!$this->haberler->contains($haberler)) {
            $this->haberler[] = $haberler;
            $haberler->setKategori($this);
        }

        return $this;
    }

    public function removeHaberler(Haberler $haberler): self
    {
        if ($this->haberler->removeElement($haberler)) {
            // set the owning side to null (unless already changed)
            if ($haberler->getKategori() === $this) {
                $haberler->setKategori(null);
            }
        }

        return $this;
    }

    public function getSeourl(): ?string
    {
        return $this->seourl;
    }

    public function setSeourl(string $seourl): self
    {
        $this->seourl = $seourl;

        return $this;
    }

    public function getTitle(): ?string
    {
        return $this->title;
    }

    public function setTitle(string $title): self
    {
        $this->title = $title;

        return $this;
    }

    public function getKeywords(): ?string
    {
        return $this->keywords;
    }

    public function setKeywords(?string $keywords): self
    {
        $this->keywords = $keywords;

        return $this;
    }

    public function getDescription(): ?string
    {
        return $this->description;
    }

    public function setDescription(?string $description): self
    {
        $this->description = $description;

        return $this;
    }

    public function getAdi(): ?string
    {
        return $this->adi;
    }

    public function setAdi(string $adi): self
    {
        $this->adi = $adi;

        return $this;
    }

    public function getUstid(): ?int
    {
        return $this->ustid;
    }

    public function setUstid(int $ustid): self
    {
        $this->ustid = $ustid;

        return $this;
    }

    public function getResim(): ?string
    {
        return $this->resim;
    }

    public function setResim(?string $resim): self
    {
        $this->resim = $resim;

        return $this;
    }

    public function getDilgrup(): ?int
    {
        return $this->dilgrup;
    }

    public function setDilgrup(int $dilgrup): self
    {
        $this->dilgrup = $dilgrup;

        return $this;
    }

    public function getSira(): ?int
    {
        return $this->sira;
    }

    public function setSira(int $sira): self
    {
        $this->sira = $sira;

        return $this;
    }

    public function getSayfa(): ?Sayfa
    {
        return $this->sayfa;
    }

    public function setSayfa(?Sayfa $sayfa): self
    {
        $this->sayfa = $sayfa;

        return $this;
    }

    public function getDil(): ?Dil
    {
        return $this->dil;
    }

    public function setDil(?Dil $dil): self
    {
        $this->dil = $dil;

        return $this;
    }
}
