<?php

namespace App\Entity;

use App\Repository\SayfaRepository;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;

/**
 * @ORM\Entity(repositoryClass=SayfaRepository::class)
 */
class Sayfa
{
    /**
     * @ORM\Id
     * @ORM\GeneratedValue
     * @ORM\Column(type="integer")
     */
    private $id;

    /**
     * @ORM\Column(type="string", length=255)
     */
    private $adi;

    /**
     * @ORM\Column(type="boolean")
     */
    private $bannerDurum;

    /**
     * @ORM\Column(type="string", length=255, nullable=true)
     */
    private $bannerUrl;

    /**
     * @ORM\Column(type="string", length=255)
     */
    private $title;

    /**
     * @ORM\Column(type="string", length=255)
     */
    private $seo;

    /**
     * @ORM\Column(type="text", nullable=true)
     */
    private $keywords;

    /**
     * @ORM\Column(type="text", nullable=true)
     */
    private $description;

    /**
     * @ORM\Column(type="integer")
     */
    private $dilgrup;

    /**
     * @ORM\Column(type="integer")
     */
    private $sira;

    /**
     * @ORM\Column(type="boolean")
     */
    private $menu;

    /**
     * @ORM\Column(type="boolean")
     */
    private $anasayfa;

    /**
     * @ORM\Column(type="boolean")
     */
    private $footer;

    /**
     * @ORM\Column(type="boolean")
     */
    private $kategori;

    /**
     * @ORM\Column(type="boolean")
     */
    private $tekVeri;

    /**
     * @ORM\Column(type="boolean")
     */
    private $icIcerik;

    /**
     * @ORM\Column(type="string", length=255, nullable=true)
     */
    private $resimBoyut;

    /**
     * @ORM\OneToMany(targetEntity=Kategori::class, mappedBy="sayfa")
     */
    private $kat;

    /**
     * @ORM\ManyToOne(targetEntity=Dil::class, inversedBy="sayfa")
     * @ORM\JoinColumn(nullable=false)
     */
    private $dil;

    /**
     * @ORM\ManyToOne(targetEntity=Modul::class, inversedBy="sayfa")
     * @ORM\JoinColumn(nullable=false)
     */
    private $modul;

    /**
     * @ORM\OneToMany(targetEntity=Kurumsal::class, mappedBy="sayfa", orphanRemoval=true)
     */
    private $kurumsal;

    /**
     * @ORM\OneToMany(targetEntity=Iletisim::class, mappedBy="sayfa", orphanRemoval=true)
     */
    private $iletisim;

    /**
     * @ORM\OneToMany(targetEntity=Hizmetler::class, mappedBy="sayfa", orphanRemoval=true)
     */
    private $hizmetler;

    /**
     * @ORM\OneToMany(targetEntity=Footermetin::class, mappedBy="sayfa", orphanRemoval=true)
     */
    private $footermetin;

    /**
     * @ORM\OneToMany(targetEntity=Bossayfa::class, mappedBy="sayfa", orphanRemoval=true)
     */
    private $bossayfa;

    /**
     * @ORM\OneToMany(targetEntity=Haberler::class, mappedBy="sayfa", orphanRemoval=true)
     */
    private $haberler;

    public function __construct()
    {
       $this->kurumsal = new ArrayCollection();
       $this->iletisim = new ArrayCollection();
       $this->hizmetler = new ArrayCollection();
       $this->footermetin = new ArrayCollection();
       $this->bossayfa = new ArrayCollection();
       $this->haberler = new ArrayCollection();
        $this->kat = new ArrayCollection();
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    /**
     * @return Collection|Kurumsal[]
     */
    public function getKurumsal(): Collection
    {
        return $this->kurumsal;
    }
    
    public function addKurumsal(Kurumsal $kurumsal): self
    {
        if (!$this->kurumsal->contains($kurumsal)) {
            $this->kurumsal[] = $kurumsal;
            $kurumsal->setSayfa($this);
        }

        return $this;
    }

    public function removeKurumsal(Kurumsal $kurumsal): self
    {
        if ($this->kurumsal->removeElement($kurumsal)) {
            // set the owning side to null (unless already changed)
            if ($kurumsal->getSayfa() === $this) {
                $kurumsal->setSayfa(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|Iletisim[]
     */
    public function getIletisim(): Collection
    {
        return $this->iletisim;
    }
    
    public function addIletisim(Iletisim $iletisim): self
    {
        if (!$this->iletisim->contains($iletisim)) {
            $this->iletisim[] = $iletisim;
            $iletisim->setSayfa($this);
        }

        return $this;
    }

    public function removeIletisim(Iletisim $iletisim): self
    {
        if ($this->iletisim->removeElement($iletisim)) {
            // set the owning side to null (unless already changed)
            if ($iletisim->getSayfa() === $this) {
                $iletisim->setSayfa(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|Hizmetler[]
     */
    public function getHizmetler(): Collection
    {
        return $this->hizmetler;
    }
    
    public function addHizmetler(Hizmetler $hizmetler): self
    {
        if (!$this->hizmetler->contains($hizmetler)) {
            $this->hizmetler[] = $hizmetler;
            $hizmetler->setSayfa($this);
        }

        return $this;
    }

    public function removeHizmetler(Hizmetler $hizmetler): self
    {
        if ($this->hizmetler->removeElement($hizmetler)) {
            // set the owning side to null (unless already changed)
            if ($hizmetler->getSayfa() === $this) {
                $hizmetler->setSayfa(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|Footermetin[]
     */
    public function getFootermetin(): Collection
    {
        return $this->footermetin;
    }
    
    public function addFootermetin(Footermetin $footermetin): self
    {
        if (!$this->footermetin->contains($footermetin)) {
            $this->footermetin[] = $footermetin;
            $footermetin->setSayfa($this);
        }

        return $this;
    }

    public function removeFootermetin(Footermetin $footermetin): self
    {
        if ($this->footermetin->removeElement($footermetin)) {
            // set the owning side to null (unless already changed)
            if ($footermetin->getSayfa() === $this) {
                $footermetin->setSayfa(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|Bossayfa[]
     */
    public function getBossayfa(): Collection
    {
        return $this->bossayfa;
    }
    
    public function addBossayfa(Bossayfa $bossayfa): self
    {
        if (!$this->bossayfa->contains($bossayfa)) {
            $this->bossayfa[] = $bossayfa;
            $bossayfa->setSayfa($this);
        }

        return $this;
    }

    public function removeBossayfa(Bossayfa $bossayfa): self
    {
        if ($this->bossayfa->removeElement($bossayfa)) {
            // set the owning side to null (unless already changed)
            if ($bossayfa->getSayfa() === $this) {
                $bossayfa->setSayfa(null);
            }
        }

        return $this;
    }

    /**
     * @return Collection|Haberler[]
     */
    public function getHaberler(): Collection
    {
        return $this->haberler;
    }
    
    public function addHaberler(Haberler $haberler): self
    {
        if (!$this->haberler->contains($haberler)) {
            $this->haberler[] = $haberler;
            $haberler->setSayfa($this);
        }

        return $this;
    }

    public function removeHaberler(Haberler $haberler): self
    {
        if ($this->haberler->removeElement($haberler)) {
            // set the owning side to null (unless already changed)
            if ($haberler->getSayfa() === $this) {
                $haberler->setSayfa(null);
            }
        }

        return $this;
    }

    public function getAdi(): ?string
    {
        return $this->adi;
    }

    public function setAdi(string $adi): self
    {
        $this->adi = $adi;

        return $this;
    }

    public function getBannerDurum(): ?bool
    {
        return $this->bannerDurum;
    }

    public function setBannerDurum(bool $bannerDurum): self
    {
        $this->bannerDurum = $bannerDurum;

        return $this;
    }

    public function getBannerUrl(): ?string
    {
        return $this->bannerUrl;
    }

    public function setBannerUrl(?string $bannerUrl): self
    {
        $this->bannerUrl = $bannerUrl;

        return $this;
    }

    public function getTitle(): ?string
    {
        return $this->title;
    }

    public function setTitle(string $title): self
    {
        $this->title = $title;

        return $this;
    }

    public function getSeo(): ?string
    {
        return $this->seo;
    }

    public function setSeo(string $seo): self
    {
        $this->seo = $seo;

        return $this;
    }

    public function getKeywords(): ?string
    {
        return $this->keywords;
    }

    public function setKeywords(?string $keywords): self
    {
        $this->keywords = $keywords;

        return $this;
    }

    public function getDescription(): ?string
    {
        return $this->description;
    }

    public function setDescription(?string $description): self
    {
        $this->description = $description;

        return $this;
    }

    public function getDilgrup(): ?int
    {
        return $this->dilgrup;
    }

    public function setDilgrup(int $dilgrup): self
    {
        $this->dilgrup = $dilgrup;

        return $this;
    }

    public function getSira(): ?int
    {
        return $this->sira;
    }

    public function setSira(int $sira): self
    {
        $this->sira = $sira;

        return $this;
    }

    public function getMenu(): ?bool
    {
        return $this->menu;
    }

    public function setMenu(bool $menu): self
    {
        $this->menu = $menu;

        return $this;
    }

    public function getAnasayfa(): ?bool
    {
        return $this->anasayfa;
    }

    public function setAnasayfa(bool $anasayfa): self
    {
        $this->anasayfa = $anasayfa;

        return $this;
    }

    public function getFooter(): ?bool
    {
        return $this->footer;
    }
 
    public function setFooter(bool $footer): self
    {
        $this->footer = $footer;

        return $this;
    }

    public function getKategori(): ?bool
    {
        return $this->kategori;
    }

    public function setKategori(bool $kategori): self
    {
        $this->kategori = $kategori;

        return $this;
    }

    public function getTekVeri(): ?bool
    {
        return $this->tekVeri;
    }

    public function setTekVeri(bool $tekVeri): self
    {
        $this->tekVeri = $tekVeri;

        return $this;
    }

    public function getIcIcerik(): ?bool
    {
        return $this->icIcerik;
    }

    public function setIcIcerik(bool $icIcerik): self
    {
        $this->icIcerik = $icIcerik;

        return $this;
    }

    public function getResimBoyut(): ?string
    {
        return $this->resimBoyut;
    }

    public function setResimBoyut(?string $resimBoyut): self
    {
        $this->resimBoyut = $resimBoyut;

        return $this;
    }

    /**
     * @return Collection|Kategori[]
     */
    public function getKat(): Collection
    {
        return $this->kat;
    }

    public function addKat(Kategori $kat): self
    {
        if (!$this->kat->contains($kat)) {
            $this->kat[] = $kat;
            $kat->setSayfa($this);
        }

        return $this;
    }

    public function removeKat(Kategori $kat): self
    {
        if ($this->kat->removeElement($kat)) {
            // set the owning side to null (unless already changed)
            if ($kat->getSayfa() === $this) {
                $kat->setSayfa(null);
            }
        }

        return $this;
    }

    public function getDil(): ?Dil
    {
        return $this->dil;
    }

    public function setDil(?Dil $dil): self
    {
        $this->dil = $dil;

        return $this;
    }

    public function getModul(): ?Modul
    {
        return $this->modul;
    }

    public function setModul(?Modul $modul): self
    {
        $this->modul = $modul;

        return $this;
    }
}
